@@ -374,5 +374,5 @@ class ListingResource:
         }
         endpoint = "listings/batch"
         
-        response = await self.session.async_request(endpoint, params=RequestEncodingMixin._encode_params(params))
+        response = await self.session.async_request(endpoint, params=params)
         return Response[Listing](**response)
\ No newline at end of file
